**Example 1: 导出自定义弱口令**



Input: 

```
tccli cwp ExportBaselineWeakPasswordList --cli-unfold-argument  \
    --ExportAll 1
```

Output: 
```
{
    "Response": {
        "RequestId": "7540ea91-97fa-436d-ba58-39005176a063"
    }
}
```

